Learn R Programming

NPMPM (version 1.0)

onestep: calculates the bacterial count at the end of a process step

Description

calculates the bacterial count at the end of a process step, default method onestep assumes the set of cfus to be normally distributed, method disconestep uses its frequency distribution

Usage

onestep(cfu_in, pstep, pdistpsteps, apsomvmethod, intexmethod) disconestep(cfu_in, pstep, pdistpsteps, apsomvmethod, intexmethod)

Arguments

cfu_in
initial bacterial concentration
pstep
pstep is one row of psteps <- data.frame(name, id, process_id, temp_min, temp_max, time_min, time_max, matrix_id, factor, stepnumber)
pdistpsteps
method for determining the process step duration
apsomvmethod
method for selection of series of measured values
intexmethod
interpolation method

Value

one bacterial concentration (in cfu/ml)