onestep:
calculates the bacterial count at the end of a process step
Description
calculates the bacterial count at the end of a process step,
default method onestep assumes the set of cfus to be normally distributed,
method disconestep uses its frequency distribution